@@ -2,6 +2,7 @@
 use std::path::PathBuf;
 
 use holochain_conductor_api::config::conductor::ConductorConfig;
+use holochain_conductor_api::config::conductor::KeystoreConfig;
 
 /// Name of the file that conductor config is written to.
 pub const CONDUCTOR_CONFIG: &str = "conductor-config.yaml";
@@ -15,7 +16,10 @@ pub fn create_config(environment_path: PathBuf) -> ConductorConfig {
     };
     let mut keystore_path = environment_path;
     keystore_path.push("keystore");
-    conductor_config.keystore_path = Some(keystore_path);
+    conductor_config.keystore = KeystoreConfig::LairServerLegacyDeprecated {
+        keystore_path: Some(keystore_path),
+        danger_passphrase_insecure_from_config: "default-insecure-passphrase".into(),
+    };
     conductor_config
 }
 
